@@ -1,13 +1,9 @@
 from cognite.experimental.data_classes.annotations import *
+from cognite.experimental.data_classes.annotations_v2 import *
 from cognite.experimental.data_classes.assets import *
 from cognite.experimental.data_classes.contextualization import *
 from cognite.experimental.data_classes.extractionpipelineruns import *
 from cognite.experimental.data_classes.extractionpipelines import *
 from cognite.experimental.data_classes.functions import *
 from cognite.experimental.data_classes.geospatial import *
-from cognite.experimental.data_classes.transformation_jobs import *
-from cognite.experimental.data_classes.transformation_notifications import *
-from cognite.experimental.data_classes.transformation_schedules import *
-from cognite.experimental.data_classes.transformation_schema import *
-from cognite.experimental.data_classes.transformations import *
 from cognite.experimental.data_classes.types import *
